**This file provides data analysis for Bushong, Schwartzstein and Rabin**
**Data collected via Qualtrics**

********************************

*EXPERIMENT 2 - Real Effort*

********************************

*Note for relication:
*The important choice variables are titled wide_effort_* and 
*wide_money_*. 

*Each participant either faced wide_effort alternatives or wide_money
*alternatives. 

* wide_effort_14 and wide_money_14 correspond to the same bundle -> 
* wide_effort_14 == wide_effort_14 == (14 tasks, $2.20)

* Likewise wide_effort_18 and wide_money_18 correspond to the same bundle -> 
*	wide_effort_18 == wide_money_18 == (18 tasks, $2.80) 

*Finally, the best and worst alternatives correspond to alternatives A, A', D, D' from 
*text. 

*Note that choice data is coded in terms of the ranking where LOWER numbers are 
*higher ranked. So the most preferred alternative is coded as 1; least 4.


********************************

*LOADING AND CLEANING*

********************************

*Load data 
*Note to user that you will need to point this to the appropriate file.

use "./Data/RealEffort.dta", clear

*Drop incomplete surveys
drop if incomplete == 1 

*Recode numeric values and generate a combined choice metric
gen high_effort_2ndchoice = 0 
replace high_effort_2ndchoice = 1 if wide_effort_18tasks == 2 | wide_money_18tasks == 2 
 
*Examining whether high_effort > lower_effort, regardless of order of rankings 
gen highabovelow = 0 
replace highabovelow = 1 if wide_effort_18 < wide_effort_14 | wide_money_18 < wide_money_14 
 

********************************

*Completion time information

*(Reported in text)

********************************

summarize durationinseconds, detail 
 
*Setup Excel sheet for results
*Note to user that you will need to point this to the appropriate location.
putexcel set RealEffort_Results.xls, sheet("Real Effort Experiment Duration") replace

**BELOW THIS LINE EXPORTS RESULTS ABOVE TO EXCEL**
putexcel A1=("Experiment Duration (Seconds)") B1=(r(mean)), nformat("#.#") 

*Average completion time of task
gen CompletionTime = (Time1_Pa+Time2_Pa+Time3_Pa+Time4_Pa+Time5_Pa) / 5
summarize CompletionTime, detail

**BELOW THIS LINE EXPORTS RESULTS ABOVE TO EXCEL**
putexcel A3=("Average Task Completion Time (Seconds)") B3=(r(mean)), nformat("#.#") 

********************************

*Results

********************************

*The statistical test below reported in the text
*This does not restrict the sample and solely counts if the person picked C > B

tabulate highabovelow dum_wide_effort, exact matcell(cellcounts)
matrix colnames cellcounts = "Wide Money" "Wide Effort"
matrix rownames cellcounts = "B higher than C"  "C higher than B"
putexcel set RealEffort_Results.xls, sheet("Table 3 Replication") modify
putexcel A1 = matrix(cellcounts), names hcenter
putexcel A4 = "P-Value (Fisher's Exact)" B4 =(r(p1_exact))

********************************

*Table 3 Replication 

********************************

*Each line below generates values in subsequent rows of the table as commented
*A>B>C>D
count if wide_effort_best < wide_effort_14 & wide_effort_14 < wide_effort_18 ///
	& wide_effort_18 < wide_effort_worst
putexcel B6 = "Wide Money" C6 = "Wide Effort" A7 = "A>B>C>D (count)" C7 = (r(N))
count if wide_money_best < wide_money_14 & wide_money_14 < wide_money_18 ///
	& wide_money_18 < wide_money_worst
putexcel B7 = (r(N))

*A>C>B>D
count if wide_effort_best < wide_effort_18 & wide_effort_18 < wide_effort_14 ///
	& wide_effort_14 < wide_effort_worst
putexcel A9 = "A>C>B>D (count)" C9 = (r(N))
count if wide_money_best < wide_money_18 & wide_money_18 < wide_money_14 ///
	& wide_money_14 < wide_money_worst
putexcel B9 = (r(N))

*B highest
count if wide_effort_14==1
putexcel A11 = "B highest (count)" C11 = (r(N))
count if wide_money_14==1
putexcel B11 = (r(N))


*C highest 
count if wide_effort_18==1
putexcel A13 = "B highest (count)" C13 = (r(N))
count if wide_money_18==1
putexcel B13 = (r(N))

*The "Other" line is populated by subtraction* 



********************************

*Results, ANALYSIS SAMPLE

*(Reported in text)

******************************** 
 
  
*Drop any people whose choices do not rank best and worst appropriately
drop if wide_money_worst == 1
drop if wide_money_worst == 2
drop if wide_money_worst == 3
drop if wide_money_best == 2
drop if wide_money_best == 3
drop if wide_money_best == 4
drop if wide_effort_worst == 1
drop if wide_effort_worst == 2
drop if wide_effort_worst == 3
drop if wide_effort_best == 2
drop if wide_effort_best == 3
drop if wide_effort_best == 4

*The statistical test below reported in the text
tabulate highabovelow dum_wide_effort, exact matcell(cellcounts)
matrix colnames cellcounts = "Wide Money" "Wide Effort"
matrix rownames cellcounts = "B higher than C"  "C higher than B"
putexcel set RealEffort_Results.xls, sheet("(Restricted) Analysis Sample") modify
putexcel A3 = matrix(cellcounts), names hcenter
putexcel A1 = "Dropped people who do not rank best and worst in correct order" A6 = "P-Value (Fisher's Exact)" B6 =(r(p1_exact))


*Drop any people whose IP addresses are listed twice
drop if flag == 1  

tabulate highabovelow dum_wide_effort, exact matcell(cellcounts)
matrix colnames cellcounts = "Wide Money" "Wide Effort"
matrix rownames cellcounts = "B higher than C"  "C higher than B"
putexcel set RealEffort_Results.xls, sheet("(Restricted) Analysis Sample") modify
putexcel A10 = matrix(cellcounts), names hcenter
putexcel A8 = "Drop any people whose IP addresses are listed twice" A13 = "P-Value (Fisher's Exact)" B13 =(r(p1_exact))


********************************

*Table A2 Replication 
*(Appendix)

*COMPLETE CHOICE ANALYSIS

********************************

********************************

*NOTE: USER MUST RELOAD STARTING DATA*

*(Code below identical to code above)

********************************

*Load data 
*Note to user that you will need to point this to the appropriate file.
use "./Data/RealEffort.dta", clear
*Drop incomplete surveys
drop if incomplete == 1 
*Recode numeric values and generate a combined choice metric
gen high_effort_2ndchoice = 0 
replace high_effort_2ndchoice = 1 if wide_effort_18tasks == 2 | wide_money_18tasks == 2 
*Examining whether high_effort > lower_effort, regardless of order of rankings 
gen highabovelow = 0 
replace highabovelow = 1 if wide_effort_18 < wide_effort_14 | wide_money_18 < wide_money_14 
 

*B>C and A>D*
count if wide_effort_14 < wide_effort_18 & wide_effort_worst > wide_effort_best
putexcel set RealEffort_Results.xls, sheet("Table A2 Replication") modify
putexcel A2 = "B>C and A>D (count)" B1 = "Wide Effort" C1 = "Wide Money" B2 = (r(N))
count if wide_money_14 < wide_money_18 & wide_money_worst > wide_money_best
putexcel C2 = (r(N))

*C>B and A>D*
count if wide_effort_14 > wide_effort_18 & wide_effort_worst > wide_effort_best
putexcel A3 = "C>B and A>D (count)" B3 = (r(N))
count if wide_money_14 > wide_money_18 & wide_money_worst > wide_money_best
putexcel C3 = (r(N))
 
*B>C or D>A*
count if wide_effort_14 < wide_effort_18 | wide_effort_worst < wide_effort_best
putexcel A4 = "B>C or D>A (count)" B4 = (r(N))
count if wide_money_14 < wide_money_18 | wide_money_worst < wide_money_best
putexcel C4 = (r(N))
 
*C>B or D>A*
count if wide_effort_14 > wide_effort_18 | wide_effort_worst < wide_effort_best
putexcel A5 = "C>B or D>A (count)" B5 = (r(N))
count if wide_money_14 > wide_money_18 | wide_money_worst < wide_money_best
putexcel C5 = (r(N))
 
 
********************************

*SUPPLEMENTAL: ALL CHOICE COMBINATIONS

*(Unpublished)

********************************

*A = Best outcome
*B = Low Effort
*C = High Pay
*D = Worst outcome 

*See Bushong, Rabin, and Schwartzstein text for choice set details

********************************

********************************
*WIDE EFFORT
********************************

*ABCD
count if wide_effort_best == 1 & wide_effort_14 == 2 & wide_effort_18 == 3 & wide_effort_worst == 4
*ABDC
count if wide_effort_best == 1 & wide_effort_14 == 2 & wide_effort_18 == 4 & wide_effort_worst == 3
*ACBD
count if wide_effort_best == 1 & wide_effort_14 == 3 & wide_effort_18 == 2 & wide_effort_worst == 4
*ACDB
count if wide_effort_best == 1 & wide_effort_14 == 4 & wide_effort_18 == 2 & wide_effort_worst == 3
*ADBC
count if wide_effort_best == 1 & wide_effort_14 == 4 & wide_effort_18 == 3 & wide_effort_worst == 2
*ADCB
count if wide_effort_best == 1 & wide_effort_14 == 3 & wide_effort_18 == 4 & wide_effort_worst == 2
*DBCA
count if wide_effort_best == 4 & wide_effort_14 == 2 & wide_effort_18 == 3 & wide_effort_worst == 1
*DBAC
count if wide_effort_best == 3 & wide_effort_14 == 2 & wide_effort_18 == 4 & wide_effort_worst == 1
*DCBA
count if wide_effort_best == 4 & wide_effort_14 == 3 & wide_effort_18 == 2 & wide_effort_worst == 1
*DCAB
count if wide_effort_best == 3 & wide_effort_14 == 4 & wide_effort_18 == 2 & wide_effort_worst == 1
*DABC
count if wide_effort_best == 2 & wide_effort_14 == 3 & wide_effort_18 == 4 & wide_effort_worst == 1
*DACB
count if wide_effort_best == 2 & wide_effort_14 == 4 & wide_effort_18 == 3 & wide_effort_worst == 1
*BACD
count if wide_effort_best == 2 & wide_effort_14 == 1 & wide_effort_18 == 3 & wide_effort_worst == 4
*BADC
count if wide_effort_best == 2 & wide_effort_14 == 1 & wide_effort_18 == 4 & wide_effort_worst == 3
*BCAD
count if wide_effort_best == 3 & wide_effort_14 == 1 & wide_effort_18 == 2 & wide_effort_worst == 4
*BCDA
count if wide_effort_best == 4 & wide_effort_14 == 1 & wide_effort_18 == 2 & wide_effort_worst == 3
*BDAC
count if wide_effort_best == 3 & wide_effort_14 == 1 & wide_effort_18 == 4 & wide_effort_worst == 2
*BDCA
count if wide_effort_best == 4 & wide_effort_14 == 1 & wide_effort_18 == 3 & wide_effort_worst == 2
*CABD
count if wide_effort_best == 2 & wide_effort_14 == 3 & wide_effort_18 == 1 & wide_effort_worst == 4
*CADB
count if wide_effort_best == 2 & wide_effort_14 == 4 & wide_effort_18 == 1 & wide_effort_worst == 3
*CBAD
count if wide_effort_best == 3 & wide_effort_14 == 2 & wide_effort_18 == 1 & wide_effort_worst == 4
*CBDA
count if wide_effort_best == 4 & wide_effort_14 == 2 & wide_effort_18 == 1 & wide_effort_worst == 3
*CDAB
count if wide_effort_best == 3 & wide_effort_14 == 4 & wide_effort_18 == 1 & wide_effort_worst == 2
*CDBA
count if wide_effort_best == 4 & wide_effort_14 == 3 & wide_effort_18 == 1 & wide_effort_worst == 2


*WIDE MONEY

*ABCD
count if wide_money_best == 1 & wide_money_14 == 2 & wide_money_18 == 3 & wide_money_worst == 4
*ABDC
count if wide_money_best == 1 & wide_money_14 == 2 & wide_money_18 == 4 & wide_money_worst == 3
*ACBD
count if wide_money_best == 1 & wide_money_14 == 3 & wide_money_18 == 2 & wide_money_worst == 4
*ACDB
count if wide_money_best == 1 & wide_money_14 == 4 & wide_money_18 == 2 & wide_money_worst == 3
*ADBC
count if wide_money_best == 1 & wide_money_14 == 4 & wide_money_18 == 3 & wide_money_worst == 2
*ADCB
count if wide_money_best == 1 & wide_money_14 == 3 & wide_money_18 == 4 & wide_money_worst == 2
*DBCA
count if wide_money_best == 4 & wide_money_14 == 2 & wide_money_18 == 3 & wide_money_worst == 1
*DBAC
count if wide_money_best == 3 & wide_money_14 == 2 & wide_money_18 == 4 & wide_money_worst == 1
*DCBA
count if wide_money_best == 4 & wide_money_14 == 3 & wide_money_18 == 2 & wide_money_worst == 1
*DCAB
count if wide_money_best == 3 & wide_money_14 == 4 & wide_money_18 == 2 & wide_money_worst == 1
*DABC
count if wide_money_best == 2 & wide_money_14 == 3 & wide_money_18 == 4 & wide_money_worst == 1
*DACB
count if wide_money_best == 2 & wide_money_14 == 4 & wide_money_18 == 3 & wide_money_worst == 1
*BACD
count if wide_money_best == 2 & wide_money_14 == 1 & wide_money_18 == 3 & wide_money_worst == 4
*BADC
count if wide_money_best == 2 & wide_money_14 == 1 & wide_money_18 == 4 & wide_money_worst == 3
*BCAD
count if wide_money_best == 3 & wide_money_14 == 1 & wide_money_18 == 2 & wide_money_worst == 4
*BCDA
count if wide_money_best == 4 & wide_money_14 == 1 & wide_money_18 == 2 & wide_money_worst == 3
*BDAC
count if wide_money_best == 3 & wide_money_14 == 1 & wide_money_18 == 4 & wide_money_worst == 2
*BDCA
count if wide_money_best == 4 & wide_money_14 == 1 & wide_money_18 == 3 & wide_money_worst == 2
*CABD
count if wide_money_best == 2 & wide_money_14 == 3 & wide_money_18 == 1 & wide_money_worst == 4
*CADB
count if wide_money_best == 2 & wide_money_14 == 4 & wide_money_18 == 1 & wide_money_worst == 3
*CBAD
count if wide_money_best == 3 & wide_money_14 == 2 & wide_money_18 == 1 & wide_money_worst == 4
*CBDA
count if wide_money_best == 4 & wide_money_14 == 2 & wide_money_18 == 1 & wide_money_worst == 3
*CDAB
count if wide_money_best == 3 & wide_money_14 == 4 & wide_money_18 == 1 & wide_money_worst == 2
*CDBA
count if wide_money_best == 4 & wide_money_14 == 3 & wide_money_18 == 1 & wide_money_worst == 2



