**This file provides data analysis for Bushong, Rabin, and Schwartzstein **
**Data collected via Qualtrics**

********************************

*EXPERIMENT 1 - Vignettes*

********************************

*Note for replication:
*Raw choice data is coded in terms of the option number they chose. This is explanined below:

*LAPTOP / HEADPHONES VIGNETTE: 
*Choice == 1 -> Drive to the other store 
*Choice == 2 -> Buy item at current location
*Choice == 3 -> Do not choose this option

*PHONE VIGNETTE: 
*Choice == 1 -> Do not fill out survey
*Choice == 2 -> Do not choose this option
*Choice == 3 -> Fill out survey

*WORK VIGNETTE: 
*Choice == 1 -> Leave for the night
*Choice == 2 -> Stay and work another table
*Choice == 3 -> Do not choose this option

*Variables d1-d4 are demographics; see supplementary table replication for details.

********************************

*LOADING AND CLEANING*

********************************

*Load data 
*Note to user that you will need to point this to the appropriate file.

 use "./Data/Vignettes.dta", clear

*Drop any people who fail the attention check
*Coding here is based on the option "Do Not Choose This Option"

drop if phone_narrow == 2
drop if phone_wide == 2
drop if tarso_narrow == 3
drop if tarso_wide == 3
drop if calc == 3
drop if jacket == 3

*Reshape data into preferred structure for statistical tests
gen dum_phone_narrow = 1
replace dum_phone_narrow = 0 if missing(phone_narrow)
gen dum_tarso_narrow = 1
replace dum_tarso_narrow = 0 if missing(tarso_narrow)
gen dum_calc = 1
replace dum_calc = 0 if missing(calc)

*Recode numeric values for ease of interpretation. This step can be ommitted
*but would require additional cleanup below.

replace phone_narrow = 0 if phone_narrow == 3
replace phone_wide = 0 if phone_wide == 3
replace tarso_narrow = 0 if tarso_narrow == 2
replace tarso_wide = 0 if tarso_wide == 2
replace calc = 0 if calc == 1 
replace jacket = 0 if jacket == 1
replace calc = 1 if calc == 2 
replace jacket = 1 if jacket == 2
gen phone = 0 
replace phone = 1 if phone_narrow == 1 | phone_wide==1
gen tarso = 0 
replace tarso = 1 if tarso_narrow == 1 | tarso_wide==1
gen jacketcalc = 0 
replace jacketcalc = 1 if calc == 1 | jacket==1


********************************

*Completion time information

*(Reported in text)

********************************

summarize durationinseconds, detail

*Setup Excel sheet for results
*Note to user that you will need to point this to the appropriate location.
putexcel set Vignettes_Results.xls, sheet("Vignettes Experiment Duration") replace

**BELOW THIS LINE EXPORTS RESULTS ABOVE TO EXCEL**
putexcel A1=("Experiment Duration (Seconds)") B1=(r(mean)), nformat("#.#") 

********************************

* Table 1 Replication and In-Text Results

********************************

*Jacket-Calculator Vignette
tabulate jacketcalc dum_calc, exact matcell(cellcounts)
**BELOW THIS LINE EXPORTS RESULTS ABOVE TO EXCEL**
matrix colnames cellcounts = "Laptop Vignette" "Headphones Vignette"
matrix rownames cellcounts = "Buy item at current location"  "Drive to the other store"
putexcel set Vignettes_Results.xls, sheet("Table 1 Replication") modify
putexcel A1 = matrix(cellcounts), names hcenter
putexcel A5 = "P-Value (Fisher's Exact)" B5 =(r(p1_exact))

*iPhone Vignette
tabulate phone dum_phone_narrow, exact matcell(cellcounts)
**BELOW THIS LINE EXPORTS RESULTS ABOVE TO EXCEL**
matrix colnames cellcounts = "Phone Vignette Wide Treatment" "Phone Vignette Narrow Treatment"
matrix rownames cellcounts = "Do not fill out survey"  "Fill out survey"
putexcel A7 = matrix(cellcounts), names hcenter
putexcel A11 = "P-Value (Fisher's Exact)" B11 =(r(p1_exact))

*Wage Uncertainty Vignette
tabulate tarso dum_tarso_narrow, exact matcell(cellcounts)
**BELOW THIS LINE EXPORTS RESULTS ABOVE TO EXCEL**
matrix colnames cellcounts = "Work Vignette Wide Treatment" "Work Vignette Narrow Treatment"
matrix rownames cellcounts = "Leave for the night"  "Stay and work another table"
putexcel A13 = matrix(cellcounts), names hcenter
putexcel A17 = "P-Value (Fisher's Exact)" B17 =(r(p1_exact))


********************************

*Table A1 Replication
*(Appendix)

*SUMMARY STATS*

********************************

rename d1 gender
gen male = 0 
replace male = 1 if gender == 1
rename d2 income 
rename d3 age 


putexcel set Vignettes_Results.xls, sheet("Table A1 Replication") modify
*Excel headers
putexcel B1= "Drive for Discount (Headphones)" C1= "Drive for Discount (Laptop)" D1 = "Survey After Purchase (Narrow)" E1 = "Survey After Purchase (Wide)" F1 = "Extra Work (Narrow)" G1 = "Extra Work (Wide)"
putexcel A2 = "Age" A3 = "(Std dev)" A5 = "Income" A6 = "(Std dev)" A8 = "% Male" A9 = "(Std dev)" 

*Each entry separately written to Excel for readability
summ age if dum_calc == 1
putexcel B2 = (r(mean)) B3 = (r(sd))

summ age if dum_calc == 0
putexcel C2 = (r(mean)) C3 = (r(sd))

summ income if dum_calc == 1
putexcel B5 = (r(mean)) B6 = (r(sd))

summ income if dum_calc == 0
putexcel C5 = (r(mean)) C6 = (r(sd))

summ male if dum_calc == 1
putexcel B8 = (r(mean)) B9 = (r(sd))

summ male if dum_calc == 0
putexcel C8 = (r(mean)) C9 = (r(sd))

**

summ age if dum_phone_narrow == 1
putexcel D2 = (r(mean)) D3 = (r(sd))

summ age if dum_phone_narrow == 0
putexcel E2 = (r(mean)) E3 = (r(sd))

summ income if dum_phone_narrow == 1
putexcel D5 = (r(mean)) D6 = (r(sd))

summ income if dum_phone_narrow == 0
putexcel E5 = (r(mean)) E6 = (r(sd))

summ male if dum_phone_narrow == 1
putexcel D8 = (r(mean)) D9 = (r(sd))

summ male if dum_phone_narrow == 0
putexcel E8 = (r(mean)) E9 = (r(sd))

**

summ age if dum_tarso_narrow == 1
putexcel F2 = (r(mean)) F3 = (r(sd))

summ age if dum_tarso_narrow == 0
putexcel G2 = (r(mean)) G3 = (r(sd))

summ income if dum_tarso_narrow == 1
putexcel F5 = (r(mean)) F6 = (r(sd))

summ income if dum_tarso_narrow == 0
putexcel G5 = (r(mean)) G6 = (r(sd))

summ male if dum_tarso_narrow == 1
putexcel F8 = (r(mean)) F9 = (r(sd))

summ male if dum_tarso_narrow == 0
putexcel G8 = (r(mean)) G9 = (r(sd))




